@@ -15,8 +15,8 @@ from foundry.game.gfx.objects.ObjectLike import (
     EXPANDS_NOT,
     EXPANDS_VERT,
 )
-from foundry.game.gfx.Palette import PaletteGroup, bg_color_for_object_set
-from foundry.game.ObjectDefinitions import EndType, GeneratorType
+from foundry.game.gfx.Palette import PaletteGroup
+from foundry.game.ObjectDefinitions import EndType, GeneratorType, TilesetDefinition
 from foundry.game.ObjectSet import ObjectSet
 from foundry.smb3parse.objects.object_set import PLAINS_OBJECT_SET
 
@@ -73,7 +73,6 @@ class LevelObject(GeneratorObject):
         self.object_set = ObjectSet(object_set)
 
         self.graphics_set = graphics_set
-        self.tsa_data = ROM.get_tsa_data(object_set)
 
         self.x_position = 0
         self.y_position = 0
@@ -138,8 +137,6 @@ class LevelObject(GeneratorObject):
 
         self.blocks = [int(block) for block in object_data.blocks]
 
-        self.block_cache = {}
-
         self.is_4byte = object_data.is_4byte
 
         if self.is_4byte and len(self.data) == 3:
@@ -156,6 +153,14 @@ class LevelObject(GeneratorObject):
 
         self._render()
 
+    @property
+    def tsa_data(self) -> bytearray:
+        return ROM.get_tsa_data(self.object_set.number)
+
+    @property
+    def definition(self) -> TilesetDefinition:
+        return self.object_set.get_definition_of(self.type)
+
     @property
     def obj_index(self):
         return self._obj_index
@@ -708,12 +713,14 @@ class LevelObject(GeneratorObject):
             self._draw_block(painter, block_index, x, y, block_length, transparent)
 
     def _draw_block(self, painter: QPainter, block_index, x, y, block_length, transparent):
-        if block_index not in self.block_cache:
-            self.block_cache[block_index] = get_block(
-                block_index, self.palette_group, self.graphics_set, bytes(self.tsa_data)
-            )
+        block = get_block(
+            block_index,
+            tuple(tuple(c for c in pal) for pal in self.palette_group),
+            self.graphics_set,
+            bytes(self.tsa_data),
+        )
 
-        self.block_cache[block_index].draw(
+        block.draw(
             painter,
             x * block_length,
             y * block_length,
@@ -927,7 +934,7 @@ class LevelObject(GeneratorObject):
             QImage.Format_RGB888,
         )
 
-        bg_color = bg_color_for_object_set(self.object_set.number, 0)
+        bg_color = self.palette_group.background_color
 
         image.fill(bg_color)
 
