@@ -1,6 +1,7 @@
 from PySide6.QtCore import QRect
 
 from foundry.core.Position import Position, PositionProtocol
+from foundry.game.Definitions import Definition
 from foundry.game.gfx.objects.ObjectLike import ObjectLike
 
 map_object_names = {
@@ -147,6 +148,10 @@ class MapObject(ObjectLike):
 
         self.selected = False
 
+    @property
+    def definition(self) -> Definition:
+        return Definition(description="Map Object", warnings=[])
+
     @property
     def position(self) -> PositionProtocol:
         return Position(self.x_position, self.y_position)
