@@ -11,12 +11,11 @@ from foundry.core.Data import Data, DataProtocol
 from foundry.game.File import ROM
 from foundry.game.gfx.objects.EnemyItem import EnemyObject
 from foundry.game.gfx.objects.LevelObject import LevelObject
-from foundry.game.gfx.Palette import restore_all_palettes
-from foundry.game.level.Level import Level, world_and_level_for_level_address
+from foundry.game.level.Level import Level, get_level_name_suggestion
 from foundry.game.level.LevelControlled import LevelControlled
 from foundry.game.level.LevelRef import LevelRef
 from foundry.gui.AutoScrollEditor import AutoScrollEditor
-from foundry.gui.BlockViewer import BlockViewer
+from foundry.gui.BlockViewer import BlockViewerController as BlockViewer
 from foundry.gui.HeaderEditor import HeaderEditor
 from foundry.gui.JumpEditor import JumpEditor
 from foundry.gui.LevelSelector import LevelSelector
@@ -83,9 +82,9 @@ class LevelController:
         enemy_address = self.level_ref.level.next_area_enemies + 1
         object_set = self.level_ref.level.next_area_object_set
 
-        world, level = world_and_level_for_level_address(level_address)
-
-        self.update_level(f"Level {world}-{level}", level_address, enemy_address, object_set)
+        self.update_level(
+            f"Level {get_level_name_suggestion(level_address + 9)}", level_address, enemy_address, object_set
+        )
 
     @require_safe_to_change
     def on_select(self):
@@ -192,6 +191,7 @@ class LevelController:
 
     def select_all(self):
         self.parent.level_view.select_all()
+        self.parent.object_list.selectAll()
 
     def focus_selected(self):
         self.parent.object_dropdown.setFocus()
@@ -275,7 +275,7 @@ class LevelController:
         self.parent.side_palette.load_from_level(self.level_ref.level)
 
     def update_gui_for_level(self):
-        restore_all_palettes()
+        self.parent.side_palette.load_from_level(self.level_ref.level)
 
         self.parent.jump_list.update()
         self.parent.object_dropdown.set_object_set(
@@ -312,8 +312,9 @@ class LevelController:
 
     def display_block_viewer(self):
         block_viewer = BlockViewer(parent=self.parent)
-        block_viewer.object_set = self.level_ref.level.object_set.number
+        block_viewer.tileset = self.level_ref.level.object_set.number
         block_viewer.palette_group = self.level_ref.level.object_palette_index
+        block_viewer.tile_square_assembly_changed.connect(self.update)
         block_viewer.show()
 
     def display_warnings(self):
