@@ -23,7 +23,8 @@ from foundry.gui.ObjectList import ObjectList
 from foundry.gui.ObjectStatusBar import ObjectStatusBar
 from foundry.gui.ObjectToolBar import ObjectToolBar
 from foundry.gui.ObjectViewer import ObjectViewer
-from foundry.gui.PaletteEditor import PaletteEditor
+from foundry.gui.PaletteGroupController import PaletteGroupController
+from foundry.gui.PlayerViewer import PlayerViewerController as PlayerViewer
 from foundry.gui.SpinnerPanel import SpinnerPanel
 from foundry.gui.Toolbar import create_toolbar
 from foundry.gui.WarningList import WarningList
@@ -40,6 +41,9 @@ class Manager(Protocol):
     def display_object_viewer(self) -> None:
         ...
 
+    def display_player_viewer(self) -> None:
+        ...
+
 
 T = TypeVar("T")
 
@@ -73,6 +77,10 @@ class LevelManager:
         self._has_warnings
         self.parent.warning_action.setEnabled(value)
 
+    def display_player_viewer(self):
+        player_viewer = PlayerViewer(self.parent)
+        player_viewer.show()
+
     def display_object_viewer(self):
         object_viewer = ObjectViewer(parent=self.parent)
 
@@ -133,9 +141,9 @@ class LevelManager:
 
         level_ref.data_changed.connect(update_enemy_size_bar)
 
-        self.parent.side_palette = PaletteEditor(self.parent)
-        self.parent.side_palette.palette_updated.connect(
-            lambda *_: self.controller.on_level_data_changed() if self.controller is not None else None
+        self.parent.side_palette = PaletteGroupController(self.parent)
+        self.parent.side_palette.palette_group_changed.connect(
+            lambda *_: self.controller.update_gui_for_level() if self.controller is not None else None
         )
 
         self.parent.jump_list = JumpList(self.parent, level_ref)
@@ -170,7 +178,10 @@ class LevelManager:
         def set_object_viewer_from_selected(items):
             if len(items) == 1:
                 self.parent.object_toolbar_viewer.icon = ObjectButton(self.parent.object_toolbar_viewer, items[0])
+                self.parent.object_dropdown.select_object(items[0])
 
+        self.parent.level_view.object_created.connect(set_object_viewer)
+        self.parent.level_view.object_created.connect(self.parent.object_dropdown.select_object)
         self.parent.object_dropdown.object_selected.connect(set_object_viewer)
         self.parent.level_view.objects_selected.connect(set_object_viewer_from_selected)
         self.parent.object_toolbar.selected.connect(set_object_viewer)
